@@ -24,7 +24,7 @@ class CFn:
     jsonb_add_key_value_elements: Final[str] = 'jsonb_add_key_value_elements'
     jsonb_array_2_bigint_array: Final[str] = 'jsonb_array_2_bigint_array'
     jsonb_array_2_int_array: Final[str] = 'jsonb_array_2_int_array'
-    fn_jsonb_2_jsonb_array: Final[str] = 'fn_jsonb_2_jsonb_array'
+    jsonb_2_jsonb_array: Final[str] = 'jsonb_2_jsonb_array'
     jsonb_array_2_smallint_array: Final[str] = 'jsonb_array_2_smallint_array'
     jsonb_array_2_text_array: Final[str] = 'jsonb_array_2_text_array'
     jsonb_remove_key: Final[str] = 'jsonb_remove_key'
