@@ -5,7 +5,7 @@ from volworld_common.api.CA import CA
 from volsite_postgres_common.db.BFn import BFn
 from volsite_postgres_common.db.CFn import CFn
 from volworld_common.test.Timer import Timer
-from volsite_postgres_common.test.db.ATestDb import ATestDb
+from volsite_postgres_common.test.db.TestDb import TestDb
 from volworld_common.util.json import print_json_by_attributes
 
 
@@ -60,7 +60,7 @@ def json_fn(fn: str, input_j: dict, conn, attList,
 
 def json_fn_db(
         fn: str, input_j: dict,
-        test_db: ATestDb, attList,
+        test_db: TestDb, attList,
         do_commit: bool = False,
         print_long_att: bool = True):  # -> dict:
     with Timer(fn):
